==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/Accounts/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	// DON'T CONVERT THESE THEY ARE MAPPINGS
	'db_name' => 'LBL_LIST_ACCOUNT_NAME',
	'db_website' => 'LBL_LIST_WEBSITE',
	'db_billing_address_city' => 'LBL_LIST_CITY',
	// END DON'T CONVERT
	// Dashlet Categories
	'LBL_CHARTS'    => 'Charts',
	'LBL_DEFAULT' => 'Views',
	'LBL_MISC'    => 'Misc',
	'LBL_UTILS'    => 'Utils',
	// END Dashlet Categories

	'ACCOUNT_REMOVE_PROJECT_CONFIRM' => 'Are you sure you want to remove this account from the project?',
	'ERR_DELETE_RECORD' => 'You must specify a record number in order to delete the account.',
	'LBL_ACCOUNT_INFORMATION' => 'Account Overview',
	'LBL_ACCOUNT_NAME' => 'Account Name:',
	'LBL_ACCOUNT' => 'Account:',
	'LBL_ACTIVITIES_SUBPANEL_TITLE'=>'Activities',
	'LBL_ADDRESS_INFORMATION' => 'Address Information',
	'LBL_ANNUAL_REVENUE' => 'Annual Revenue:',
	'LBL_ANY_ADDRESS' => 'Any Address:',
	'LBL_ANY_EMAIL' => 'Any Email:',
	'LBL_ANY_PHONE' => 'Any Phone:',
	'LBL_ASSIGNED_TO_NAME' => 'Assigned to:',
	'LBL_ASSIGNED_TO_ID' => 'Assigned User:',
	'LBL_BILLING_ADDRESS_CITY' => 'Billing City:',
	'LBL_BILLING_ADDRESS_COUNTRY' => 'Billing Country:',
	'LBL_BILLING_ADDRESS_POSTALCODE' => 'Billing Postal Code:',
	'LBL_BILLING_ADDRESS_STATE' => 'Billing State:',
	'LBL_BILLING_ADDRESS_STREET_2' =>'Billing Street 2',
	'LBL_BILLING_ADDRESS_STREET_3' =>'Billing Street 3',
	'LBL_BILLING_ADDRESS_STREET_4' =>'Billing Street 4',
	'LBL_BILLING_ADDRESS_STREET' => 'Billing Street:',
	'LBL_BILLING_ADDRESS' => 'Billing Address:',
	'LBL_BUG_FORM_TITLE' => 'Accounts',
	'LBL_BUGS_SUBPANEL_TITLE' => 'Bugs',
	'LBL_CALLS_SUBPANEL_TITLE' => 'Calls',	
	'LBL_CAMPAIGN_ID' => 'Campaign ID',
	'LBL_CASES_SUBPANEL_TITLE' => 'Cases',
	'LBL_CITY' => 'City:',
	'LBL_CONTACTS_SUBPANEL_TITLE' => 'Contacts',
	'LBL_COUNTRY' => 'Country:',
	'LBL_DATE_ENTERED' => 'Date Created:',
	'LBL_DATE_MODIFIED' => 'Date Modified:',
	'LBL_MODIFIED_ID'=>'Modified By Id',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Accounts',
	'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
	'LBL_DESCRIPTION' => 'Description:',
	'LBL_DUPLICATE' => 'Possible Duplicate Account',
	'LBL_EMAIL' => 'Email Address:',
	'LBL_EMAIL_OPT_OUT' => 'Email Opt Out:',
	//'LBL_EMAIL_ADDRESSES' => 'Email Addresses',
	'LBL_EMPLOYEES' => 'Employees:',
	'LBL_FAX' => 'Fax:',
	'LBL_HISTORY_SUBPANEL_TITLE'=>'History',
	'LBL_HOMEPAGE_TITLE' => 'My Accounts',
	'LBL_INDUSTRY' => 'Industry:',
	'LBL_INVALID_EMAIL'=>'Invalid Email:',
	'LBL_INVITEE' => 'Contacts',
	'LBL_LEADS_SUBPANEL_TITLE' => 'Leads',
	'LBL_LIST_ACCOUNT_NAME' => 'Account Name',
	'LBL_LIST_CITY' => 'City',
	'LBL_LIST_CONTACT_NAME' => 'Contact Name',
	'LBL_LIST_EMAIL_ADDRESS' => 'Email Address',
	'LBL_LIST_FORM_TITLE' => 'Account List',
	'LBL_LIST_PHONE' => 'Phone',
	'LBL_LIST_STATE' => 'State',
	'LBL_LIST_WEBSITE' => 'Website',
	'LBL_MEETINGS_SUBPANEL_TITLE' => 'Meetings',
	'LBL_MEMBER_OF' => 'Member of:',
	'LBL_MEMBER_ORG_FORM_TITLE' => 'Member Organizations',
	'LBL_MEMBER_ORG_SUBPANEL_TITLE'=>'Member Organizations',
	'LBL_MODULE_NAME' => 'Accounts',
	'LBL_MODULE_TITLE' => 'Accounts: Home',
	'LBL_MODULE_ID'=> 'Accounts',
	'LBL_NAME'=>'Name:',
	'LBL_NEW_FORM_TITLE' => 'New Account',
	'LBL_OPPORTUNITIES_SUBPANEL_TITLE' => 'Opportunities',
	'LBL_OTHER_EMAIL_ADDRESS' => 'Other Email:',
	'LBL_OTHER_PHONE' => 'Other Phone:',
	'LBL_OWNERSHIP' => 'Ownership:',
	'LBL_PARENT_ACCOUNT_ID' => 'Parent Account ID',
	'LBL_PHONE_ALT' => 'Alternate Phone:',
	'LBL_PHONE_FAX' => 'Phone Fax:',
	'LBL_PHONE_OFFICE' => 'Office Phone:',
	'LBL_PHONE' => 'Phone:',
	'LBL_POSTAL_CODE' => 'Postal Code:',
	'LBL_PRODUCTS_TITLE'=>'Products',
	'LBL_PROJECTS_SUBPANEL_TITLE' => 'Projects',
	'LBL_PUSH_BILLING' => 'Push Billing',
	'LBL_PUSH_CONTACTS_BUTTON_LABEL' => 'Copy to Contacts',
	'LBL_PUSH_CONTACTS_BUTTON_TITLE' => 'Copy...',
	'LBL_PUSH_SHIPPING' => 'Push Shipping',
	'LBL_RATING' => 'Rating:',
	'LBL_SAVE_ACCOUNT' => 'Save Account',
	'LBL_SEARCH_FORM_TITLE' => 'Account Search',
	'LBL_SHIPPING_ADDRESS_CITY' => 'Shipping City:',
	'LBL_SHIPPING_ADDRESS_COUNTRY' => 'Shipping Country:',
	'LBL_SHIPPING_ADDRESS_POSTALCODE' => 'Shipping Postal Code:',
	'LBL_SHIPPING_ADDRESS_STATE' => 'Shipping State:',
	'LBL_SHIPPING_ADDRESS_STREET_2' => 'Shipping Street 2',
	'LBL_SHIPPING_ADDRESS_STREET_3' => 'Shipping Street 3',
	'LBL_SHIPPING_ADDRESS_STREET_4' => 'Shipping Street 4',
	'LBL_SHIPPING_ADDRESS_STREET' => 'Shipping Street:',
	'LBL_SHIPPING_ADDRESS' => 'Shipping Address:',
	'LBL_SIC_CODE' => 'SIC Code:',
	'LBL_STATE' => 'State:',
	'LBL_TASKS_SUBPANEL_TITLE' => 'Tasks',
	'LBL_TEAMS_LINK'=>'Teams',
	'LBL_TICKER_SYMBOL' => 'Ticker Symbol:',
	'LBL_TYPE' => 'Type:',
	'LBL_USERS_ASSIGNED_LINK'=>'Assigned Users',
	'LBL_USERS_CREATED_LINK'=>'Created By Users',
	'LBL_USERS_MODIFIED_LINK'=>'Modified Users',
	'LBL_VIEW_FORM_TITLE' => 'Account View',
	'LBL_WEBSITE' => 'Website:',
	'LBL_CREATED_ID'=>'Created By Id',
	'LBL_CAMPAIGNS' =>'Campaigns',
	'LNK_ACCOUNT_LIST' => 'View Accounts',
	'LNK_NEW_ACCOUNT' => 'Create Account',
	'LNK_IMPORT_ACCOUNTS' => 'Import Accounts',
	'MSG_DUPLICATE' => 'The account record you are about to create might be a duplicate of a account record that already exists. Account records containing similar names are listed below.<br>Click Save to continue creating this new account, or click Cancel to return to the module without creating the account.',
	'MSG_SHOW_DUPLICATES' => 'The account record you are about to create might be a duplicate of a account record that already exists. Account records containing similar names are listed below.<br>Click Save to continue creating this new account, or click Cancel to return to the module without creating the account.',
	'NTC_COPY_BILLING_ADDRESS' => 'Copy billing address to shipping address',
	'NTC_COPY_BILLING_ADDRESS2' => 'Copy to shipping',
	'NTC_COPY_SHIPPING_ADDRESS' => 'Copy shipping address to billing address',
	'NTC_COPY_SHIPPING_ADDRESS2' => 'Copy to billing',
	'NTC_DELETE_CONFIRMATION' => 'Are you sure you want to delete this record?',
	'NTC_REMOVE_ACCOUNT_CONFIRMATION' => 'Are you sure you want to remove this record?',
	'NTC_REMOVE_MEMBER_ORG_CONFIRMATION' => 'Are you sure you want to remove this record as a member organization?',
	'LBL_ASSIGNED_USER_NAME' => 'Assigned to:',
    'LBL_PROSPECT_LIST' => 'Prospect List',
    'LBL_ACCOUNTS_SUBPANEL_TITLE'=>'Accounts',
    'LBL_PROJECT_SUBPANEL_TITLE' => 'Projects',
);
?>

==> SugarCE-6.2.1.zip: SugarCE-Full-6.2.1/modules/Accounts/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	// DON'T CONVERT THESE THEY ARE MAPPINGS
	'db_name' => 'LBL_LIST_ACCOUNT_NAME',
	'db_website' => 'LBL_LIST_WEBSITE',
	'db_billing_address_city' => 'LBL_LIST_CITY',
	// END DON'T CONVERT
    'LBL_DOCUMENTS_SUBPANEL_TITLE' => 'Documents',
	// Dashlet Categories
	'LBL_CHARTS'    => 'Charts',
	'LBL_DEFAULT' => 'Views',
	'LBL_MISC'    => 'Misc',
	'LBL_UTILS'    => 'Utils',
	// END Dashlet Categories

	'ACCOUNT_REMOVE_PROJECT_CONFIRM' => 'Are you sure you want to remove this account from the project?',
	'ERR_DELETE_RECORD' => 'You must specify a record number in order to delete the account.',
	'LBL_ACCOUNT_INFORMATION' => 'Account Overview',
	'LBL_ACCOUNT_NAME' => 'Account Name:',
	'LBL_ACCOUNT' => 'Account:',
	'LBL_ACTIVITIES_SUBPANEL_TITLE'=>'Activities',
	'LBL_ADDRESS_INFORMATION' => 'Address Information',
	'LBL_ANNUAL_REVENUE' => 'Annual Revenue:',
	'LBL_ANY_ADDRESS' => 'Any Address:',
	'LBL_ANY_EMAIL' => 'Any Email:',
	'LBL_ANY_PHONE' => 'Any Phone:',
	'LBL_ASSIGNED_TO_NAME' => 'Assigned to:',
	'LBL_ASSIGNED_TO_ID' => 'Assigned User:',
	'LBL_BILLING_ADDRESS_CITY' => 'Billing City:',
	'LBL_BILLING_ADDRESS_COUNTRY' => 'Billing Country:',
	'LBL_BILLING_ADDRESS_POSTALCODE' => 'Billing Postal Code:',
	'LBL_BILLING_ADDRESS_STATE' => 'Billing State:',
	'LBL_BILLING_ADDRESS_STREET_2' =>'Billing Street 2',
	'LBL_BILLING_ADDRESS_STREET_3' =>'Billing Street 3',
	'LBL_BILLING_ADDRESS_STREET_4' =>'Billing Street 4',
	'LBL_BILLING_ADDRESS_STREET' => 'Billing Street:',
	'LBL_BILLING_ADDRESS' => 'Billing Address:',
	'LBL_BUG_FORM_TITLE' => 'Accounts',
	'LBL_BUGS_SUBPANEL_TITLE' => 'Bugs',
	'LBL_CALLS_SUBPANEL_TITLE' => 'Calls',	
	'LBL_CAMPAIGN_ID' => 'Campaign ID',
	'LBL_CASES_SUBPANEL_TITLE' => 'Cases',
	'LBL_CITY' => 'City:',
	'LBL_CONTACTS_SUBPANEL_TITLE' => 'Contacts',
	'LBL_COUNTRY' => 'Country:',
	'LBL_DATE_ENTERED' => 'Date Created:',
	'LBL_DATE_MODIFIED' => 'Date Modified:',
	'LBL_MODIFIED_ID'=>'Modified By Id',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Accounts',
	'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
	'LBL_DESCRIPTION' => 'Description:',
	'LBL_DUPLICATE' => 'Possible Duplicate Account',
	'LBL_EMAIL' => 'Email Address:',
	'LBL_EMAIL_OPT_OUT' => 'Email Opt Out:',
	//'LBL_EMAIL_ADDRESSES' => 'Email Addresses',
	'LBL_EMPLOYEES' => 'Employees:',
	'LBL_FAX' => 'Fax:',
	'LBL_HISTORY_SUBPANEL_TITLE'=>'History',
	'LBL_HOMEPAGE_TITLE' => 'My Accounts',
	'LBL_INDUSTRY' => 'Industry:',
	'LBL_INVALID_EMAIL'=>'Invalid Email:',
	'LBL_INVITEE' => 'Contacts',
	'LBL_LEADS_SUBPANEL_TITLE' => 'Leads',
	'LBL_LIST_ACCOUNT_NAME' => 'Account Name',
	'LBL_LIST_CITY' => 'City',
	'LBL_LIST_CONTACT_NAME' => 'Contact Name',
	'LBL_LIST_EMAIL_ADDRESS' => 'Email Address',
	'LBL_LIST_FORM_TITLE' => 'Account List',
	'LBL_LIST_PHONE' => 'Phone',
	'LBL_LIST_STATE' => 'State',
	'LBL_LIST_WEBSITE' => 'Website',
	'LBL_MEETINGS_SUBPANEL_TITLE' => 'Meetings',
	'LBL_MEMBER_OF' => 'Member of:',
	'LBL_MEMBER_ORG_FORM_TITLE' => 'Member Organizations',
	'LBL_MEMBER_ORG_SUBPANEL_TITLE'=>'Member Organizations',
	'LBL_MODULE_NAME' => 'Accounts',
	'LBL_MODULE_TITLE' => 'Accounts: Home',
	'LBL_MODULE_ID'=> 'Accounts',
	'LBL_NAME'=>'Name:',
	'LBL_NEW_FORM_TITLE' => 'New Account',
	'LBL_OPPORTUNITIES_SUBPANEL_TITLE' => 'Opportunities',
	'LBL_OTHER_EMAIL_ADDRESS' => 'Other Email:',
	'LBL_OTHER_PHONE' => 'Other Phone:',
	'LBL_OWNERSHIP' => 'Ownership:',
	'LBL_PARENT_ACCOUNT_ID' => 'Parent Account ID',
	'LBL_PHONE_ALT' => 'Alternate Phone:',
	'LBL_PHONE_FAX' => 'Phone Fax:',
	'LBL_PHONE_OFFICE' => 'Office Phone:',
	'LBL_PHONE' => 'Phone:',
	'LBL_POSTAL_CODE' => 'Postal Code:',
	'LBL_PRODUCTS_TITLE'=>'Products',
	'LBL_PROJECTS_SUBPANEL_TITLE' => 'Projects',
	'LBL_PUSH_BILLING' => 'Push Billing',
	'LBL_PUSH_CONTACTS_BUTTON_LABEL' => 'Copy to Contacts',
	'LBL_PUSH_CONTACTS_BUTTON_TITLE' => 'Copy...',
	'LBL_PUSH_SHIPPING' => 'Push Shipping',
	'LBL_RATING' => 'Rating:',
	'LBL_SAVE_ACCOUNT' => 'Save Account',
	'LBL_SEARCH_FORM_TITLE' => 'Account Search',
	'LBL_SHIPPING_ADDRESS_CITY' => 'Shipping City:',
	'LBL_SHIPPING_ADDRESS_COUNTRY' => 'Shipping Country:',
	'LBL_SHIPPING_ADDRESS_POSTALCODE' => 'Shipping Postal Code:',
	'LBL_SHIPPING_ADDRESS_STATE' => 'Shipping State:',
	'LBL_SHIPPING_ADDRESS_STREET_2' => 'Shipping Street 2',
	'LBL_SHIPPING_ADDRESS_STREET_3' => 'Shipping Street 3',
	'LBL_SHIPPING_ADDRESS_STREET_4' => 'Shipping Street 4',
	'LBL_SHIPPING_ADDRESS_STREET' => 'Shipping Street:',
	'LBL_SHIPPING_ADDRESS' => 'Shipping Address:',
	'LBL_SIC_CODE' => 'SIC Code:',
	'LBL_STATE' => 'State:',
	'LBL_TASKS_SUBPANEL_TITLE' => 'Tasks',
	'LBL_TEAMS_LINK'=>'Teams',
	'LBL_TICKER_SYMBOL' => 'Ticker Symbol:',
	'LBL_TYPE' => 'Type:',
	'LBL_USERS_ASSIGNED_LINK'=>'Assigned Users',
	'LBL_USERS_CREATED_LINK'=>'Created By Users',
	'LBL_USERS_MODIFIED_LINK'=>'Modified Users',
	'LBL_VIEW_FORM_TITLE' => 'Account View',
	'LBL_WEBSITE' => 'Website:',
	'LBL_CREATED_ID'=>'Created By Id',
	'LBL_CAMPAIGNS' =>'Campaigns',
	'LNK_ACCOUNT_LIST' => 'View Accounts',
	'LNK_NEW_ACCOUNT' => 'Create Account',
	'LNK_IMPORT_ACCOUNTS' => 'Import Accounts',
	'MSG_DUPLICATE' => 'The account record you are about to create might be a duplicate of an account record that already exists. Account records containing similar names are listed below.<br>Click Create Account to continue creating this new account, or select an existing account listed below.',
	'MSG_SHOW_DUPLICATES' => 'The account record you are about to create might be a duplicate of an account record that already exists. Account records containing similar names are listed below.<br>Click Save to continue creating this new account, or click Cancel to return to the module without creating the account.',
	'NTC_COPY_BILLING_ADDRESS' => 'Copy billing address to shipping address',
	'NTC_COPY_BILLING_ADDRESS2' => 'Copy to shipping',
	'NTC_COPY_SHIPPING_ADDRESS' => 'Copy shipping address to billing address',
	'NTC_COPY_SHIPPING_ADDRESS2' => 'Copy to billing',
	'NTC_DELETE_CONFIRMATION' => 'Are you sure you want to delete this record?',
	'NTC_REMOVE_ACCOUNT_CONFIRMATION' => 'Are you sure you want to remove this record?',
	'NTC_REMOVE_MEMBER_ORG_CONFIRMATION' => 'Are you sure you want to remove this record as a member organization?',
	'LBL_ASSIGNED_USER_NAME' => 'Assigned to:',
    'LBL_PROSPECT_LIST' => 'Prospect List',
    'LBL_ACCOUNTS_SUBPANEL_TITLE'=>'Accounts',
    'LBL_PROJECT_SUBPANEL_TITLE' => 'Projects',
);
?>
